<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt_BR" version="2.1">
    <context>
        <name>desktop</name>
        <message>
            <location filename="Desktop Entry]Comment" line="0"/>
            <source>Calendar is a date tool.</source>
            <translation>Calendário é uma ferramenta de data.</translation>
        </message>
        <message>
            <location filename="Desktop Entry]Name" line="0"/>
            <source>Deepin Calendar</source>
            <translation>Calendário</translation>
        </message>
    </context>
</TS>